@@ -24,13 +24,12 @@ from urllib.parse import urlencode
 
 import nbxmpp
 from gi.repository import Gtk
-from nbxmpp.http import HTTPRequest
 
 import gajim
 from gajim.common import app
+from gajim.common.file_transfer_manager import FileTransfer
 from gajim.common.helpers import determine_proxy
 from gajim.common.i18n import _
-from gajim.common.util.http import create_http_request
 from gajim.common.util.version import get_glib_version
 from gajim.common.util.version import get_gobject_version
 from gajim.common.util.version import get_os_name
@@ -38,9 +37,9 @@ from gajim.common.util.version import get_os_version
 from gajim.common.util.version import get_soup_version
 
 from gajim.gtk.builder import get_builder
-from gajim.gtk.util.classes import SignalManager
+from gajim.gtk.util.misc import get_adw_version
 from gajim.gtk.util.misc import get_gtk_version
-from gajim.gtk.widgets import GajimAppWindow
+from gajim.gtk.window import GajimAppWindow
 
 try:
     import sentry_sdk
@@ -55,21 +54,33 @@ _exception_in_progress = threading.Lock()
 
 ISSUE_URL = "https://dev.gajim.org/gajim/gajim/issues/new"
 
-ISSUE_TEXT = """## Versions:
+ISSUE_TEXT = """## Versions
 - OS: {}
-- GTK Version: {}
-- PyGObject Version: {}
-- GLib Version : {}
-- libsoup Version: {}
-- python-nbxmpp Version: {}
-- Gajim Version: {}
+- GTK: {}
+- PyGObject: {}
+- GLib: {}
+- Adw: {}
+- libsoup: {}
+- python-nbxmpp: {}
+- Gajim: {}
 
 ## Traceback
 ```
 {}
 ```
+
 ## Steps to reproduce the problem
-..."""
+
+  1.
+  1.
+  1.
+
+## Expected behavior
+...
+
+## Actual behavior
+...
+"""
 
 
 def _hook(type_: type[BaseException], value: BaseException, tb: TracebackType) -> None:
@@ -82,7 +93,7 @@ def _hook(type_: type[BaseException], value: BaseException, tb: TracebackType) -
     ExceptionDialog(type_, value, tb)
 
 
-class ExceptionDialog(GajimAppWindow, SignalManager):
+class ExceptionDialog(GajimAppWindow):
     def __init__(
         self, type_: type[BaseException], value: BaseException, tb: TracebackType
     ) -> None:
@@ -91,9 +102,8 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
             name="ExceptionDialog",
             title=_("Gajim - Error"),
             default_width=700,
-            add_window_padding=False,
+            header_bar=True,
         )
-        SignalManager.__init__(self)
 
         self._traceback_data = (type_, value, tb)
         self._sentry_available = app.is_installed("SENTRY_SDK")
@@ -149,6 +159,7 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
             get_gtk_version(),
             get_gobject_version(),
             get_glib_version(),
+            get_adw_version(),
             get_soup_version(),
             nbxmpp.__version__,
             gajim.__version__,
@@ -169,22 +180,16 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
         self._ui.report_button.set_sensitive(False)
         self._ui.close_button.set_sensitive(False)
         self._ui.report_spinner.set_visible(True)
-        self._ui.report_spinner.start()
 
-        request = create_http_request()
-        request.send(
-            "GET", "https://gajim.org/updates.json", callback=self._on_endpoint_received
+        app.ftm.http_request(
+            "GET",
+            "https://gajim.org/updates.json",
+            callback=self._on_endpoint_received,
         )
 
-    def _parse_endpoint(self, request: HTTPRequest) -> str:
-        if not request.is_complete():
-            raise ValueError(
-                "Failed to retrieve sentry endpoint: "
-                f"{request.get_status()} {request.get_error()}"
-            )
-
+    def _parse_endpoint(self, content: bytes) -> str:
         try:
-            data = json.loads(request.get_data())
+            data = json.loads(content)
         except Exception as error:
             raise ValueError(f"Json parsing error: {error}")
 
@@ -194,11 +199,12 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
 
         return endpoint
 
-    def _on_endpoint_received(self, request: HTTPRequest) -> None:
+    def _on_endpoint_received(self, obj: FileTransfer) -> None:
         try:
-            endpoint = self._parse_endpoint(request)
-        except ValueError as error:
-            print(error)
+            result = obj.get_result()
+            endpoint = self._parse_endpoint(result.content)
+        except Exception as error:
+            print("Failed to retrieve sentry endpoint: %s" % error)
             self._report_with_browser()
 
         else:
@@ -230,6 +236,8 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
                 "GTK": get_gtk_version(),
                 "GObject": get_gobject_version(),
                 "GLib": get_glib_version(),
+                "Adw": get_adw_version(),
+                "libsoup": get_soup_version(),
             },
         )
 
@@ -256,7 +264,6 @@ class ExceptionDialog(GajimAppWindow, SignalManager):
         return event
 
     def _cleanup(self) -> None:
-        self._disconnect_all()
         _exception_in_progress.release()
 
 
